Examples of RKD file structure
==============================

NOTICE: Be careful when modifying, those files are used in automatic tests. We use those examples in unit tests, because unused examples are usually getting outdated.
